@@ -5,16 +5,12 @@ BEGIN {
         new => ["function", "any", "string"],
         swig_type_get => ["function", "integer", "any"],
         swig_type_set => ["function", "void", "any", "integer"],
-        swig_volcnt_get => ["function", "integer", "any"],
-        swig_volcnt_set => ["function", "void", "any", "integer"],
         swig_device_get => ["function", "string", "any"],
         swig_device_set => ["function", "void", "any", "string"],
         swig_name_get => ["function", "string", "any"],
         swig_name_set => ["function", "void", "any", "string"],
         swig_usedByType_get => ["function", "integer", "any"],
         swig_usedByType_set => ["function", "void", "any", "integer"],
-        swig_usedByName_get => ["function", "string", "any"],
-        swig_usedByName_set => ["function", "void", "any", "string"],
         swig_usedByDevice_get => ["function", "string", "any"],
         swig_usedByDevice_set => ["function", "void", "any", "string"],
         swig_readonly_get => ["function", "boolean", "any"],
