@@ -526,18 +526,8 @@ sub createVH (){
  if ($byname eq 0){
 	 push(@{$vhost_files->{'ip-based'}},  {HOSTID => "$ip/$servername", HostIP => $ip, DATA => \@newdata});
 	} else {
-		 $vhost_files->{$ip} =  [{HOSTID => "$ip/$servername", HostIP => $ip, DATA => \@newdata}];
+		 $vhost_files->{$servername} =  [{HOSTID => "$ip/$servername", HostIP => $ip, DATA => \@newdata}];
 		}
-
-
-
-#$vhost_files->{$ip} = \@newdata;
-#  deleteVH() if (@{$self->GetHost($hostid)} ne 0);
- 
-# if ($type eq "0"){
-#   $vhost_files->{$ip} = @newdata;
-#  }
-
 }
 
 
@@ -556,12 +546,11 @@ sub deleteVH (){
 		 }
 		}
 	 case "main" { delete $vhost_files->{'main'} if ($hostid eq 'main'); }
-	 else { 
-	       foreach my $hostList ( $vhost_files->{$key} ) {
-	           foreach my $hostentryHash ( @$hostList ) { delete ($vhost_files->{$key}) if ($hostentryHash->{HOSTID} eq $hostid); }
-		  }
-	      }
-	 }	
+	 else {
+		my $vhost = $vhost_files->{$key}->[0]->{'HOSTID'};
+		delete $vhost_files->{$key} if ($vhost eq $hostid);
+	 }
+	 }
       }
 }
 
@@ -579,17 +568,7 @@ sub modifyVH {
     my $data = shift;
 
 
-# my @newdata = ();
-# foreach my $row (@{$data}){
-#  if ($row->{KEY} eq 'HostIP' ) {
-#    $ip = $row->{VALUE};
-#   } elsif ($row->{KEY} eq 'VirtualByName' ) {
-#	 $type = $row->{VALUE};		
-#	}else {
-#	 	push(@newdata, $row);
-#	}
-# }
-my $params = $self->getVhType($hostid);
+ my $params = $self->getVhType($hostid);
 
  $self->deleteVH($hostid);
  $self->createVH($hostid, $data, $params);
@@ -781,17 +760,6 @@ sub CreateHost {
         if( $key->{KEY} eq 'VirtualByName' ) {
             $VirtualByName = $key->{VALUE};
         } 
-#elsif( $key->{KEY} eq 'SSL' and $key->{VALUE} == 1 ) {
-#            $sslHash->{'VALUE'} = 'on';
-#        } elsif( $key->{KEY} eq 'SSL' and $key->{VALUE} == 2 ) {
-#            $sslHash->{'VALUE'} = 'on';
-#            push( @tmp, { KEY => 'SSLRequireSSL', VALUE => '' } );
-#        } elsif( $key->{KEY} eq 'SSL' ) {
-#            # already set to "off" above. So ignore.
-#        } elsif( $key->{KEY} eq 'DocumentRoot' ) {
-#            $docRoot = $key->{VALUE};
-#            push( @tmp, $key );
-#        } els
 if( $key->{KEY} =~ /ServerTokens|TimeOut|ExtendedStatus/ ) {
             # illegal keys in vhost
             return $self->SetError( summary => sprintf(__("Illegal key in vhost '%s'."), $key->{KEY}),
@@ -898,28 +866,21 @@ sub DeleteHost {
 
 sub writeHosts (){
     my $self = shift;
-    my @vhosts = ();
 
-    @vhosts = @{$vhost_files->{'ip-based'}} if (defined $vhost_files->{'ip-based'}); 
+    # default server
+    my %data = ( 'default-server.conf' =>$vhost_files->{'main'});
 
-     foreach my $key ( keys(%{$vhost_files}) ) {
-	switch($key)
-	 {
-	 case "ip-based" {
-		}
-	 case "main" {}
-	 else { 
-	       foreach my $hostList ( $vhost_files->{$key} ) {
-	           foreach my $hostentryHash ( @$hostList ) {
-	               push( @vhosts, $hostentryHash ) ;
-	           }
-		  }
-	      }
-	 }	
-     }
+    #ip based vhost
+    my @ip_vhosts = @{$vhost_files->{'ip-based'}} if (defined $vhost_files->{'ip-based'}); 
+    my $size = @ip_vhosts;
+    $data{'ip-based_vhosts.conf'} = \@ip_vhosts if ($size>0);
 
- my %data = ( 'default-server.conf' =>$vhost_files->{'main'});
- $data{'yast2_vhosts.conf'} = \@vhosts ;
+    #name based vhost
+    foreach my $vhost ( keys(%{$vhost_files}) ) {
+      next if ($vhost eq 'main' || $vhost eq 'ip-based');
+      my @name_vhost = @{$vhost_files->{$vhost}};
+      $data{"$vhost.conf"} = \@name_vhost;
+    }
 
  SCR->Write(".http_server.vhosts", \%data);
 }
@@ -955,7 +916,9 @@ EXAMPLE
 BEGIN { $TYPEINFO{GetModuleList} = ["function", [ "list", "string" ] ]; }
 sub GetModuleList {
     my $self = shift;
-    my $data = SCR->Read('.sysconfig.apache2.APACHE_MODULES'); # FIXME: Error handling
+#    my $data = SCR->Read('.sysconfig.apache2.APACHE_MODULES'); # FIXME: Error handling
+    my $data = SCR->Execute('.target.bash_output', 'a2enmod -l')->{'stdout'}; # FIXME: Error handling
+
     $data =~ s/mod_//g;
 
     return [ split(/\s+/, $data) ];
@@ -1070,8 +1033,12 @@ sub ModifyModuleList {
     }
     @newList = (@known, @unknown);
 
-    SCR->Write('.sysconfig.apache2.APACHE_MODULES', join(' ',@newList));
-    SCR->Write('.sysconfig.apache2', undef);
+    SCR->Execute('.target.bash', 'for module in $(a2enmod -l);do a2enmod -d $module; done');
+    foreach my $module (@newList){
+    	SCR->Execute('.target.bash', "a2enmod $module");
+    }
+#    SCR->Write('.sysconfig.apache2.APACHE_MODULES', join(' ',@newList));
+#    SCR->Write('.sysconfig.apache2', undef);
     return 1;
 }
 
@@ -1404,6 +1371,13 @@ EXAMPLE
 
 =cut
 
+# http://httpd.apache.org/docs/2.2/mod/mpm_common.html#listen
+# We support 3 possible values for Listen :
+# [IPv6]:port
+# IPv4:port
+# port
+#
+
 BEGIN { $TYPEINFO{GetCurrentListen} = ["function", ["list", [ "map", "string", "any" ] ] ]; }
 sub GetCurrentListen {
     my $self = shift;
@@ -1413,17 +1387,16 @@ sub GetCurrentListen {
         return $self->SetError( %{SCR->Error(".http_server.listen")} );
     }
     foreach my $new ( @{$data[0]} ) {
-     my ($ip, $fp, $tp, $port) = ('', '', '', '');
+     my ($ip, $port) = ('', '');
      if ($new =~ m/\[([\w\W]*)\]([\w\W]*)/){
       $ip="[$1]";
-      if ($2 =~ m/([\d\:]*)/){
-       ($fp, $tp) = split(/:/, $1);
-      } else{
-             ( $ip, $fp, $tp ) = split(/:/, $new);
-            }
-      $fp=$tp if ($fp eq '');
-      $port = ($fp eq $tp)?($fp):($fp.'-'.$tp);
-     } elsif ($new =~/[\D]*([\d]*)[\D]*/){
+      $new=$2;
+     } elsif ($new =~ m/([\d\.]*):([\w\W]*)/){
+	$ip=$1;
+	$new=$2;
+     }
+
+     if ($new =~/[\D]*([\d]*)[\D]*/){
       $port=$1;
      }
     push(@ret, {ADDRESS => $ip, PORT=>$port});
@@ -1622,15 +1595,11 @@ sub WriteServerCert {
     $file .= '-cert.pem';
 
     if( not $pemData ) {
-#        SCR->Execute( '.target.remove', $file );
-#        $self->ModifyHostKey( $host, 'SSLCertificateFile' );
     } elsif( $pemData !~ /BEGIN CERTIFICATE/ ) {
         return $self->SetError( summary => __("Corrupt PEM data."), code => 'CERT_ERROR' );
     } else {
         SCR->Write( '.target.string', $file, $pemData );
         SCR->Execute( '.target.bash', "chmod 0400 $file" );
-#        $self->ModifyHostKey( $host, 'SSLCertificateFile', $file );
-#        $self->ModifyHostKey( $host, 'SSLCertificateKeyFile', $file ) if( $key );
     }
     return $self->ModifyHost( $hostid, $host );
 }
@@ -1673,16 +1642,12 @@ sub WriteServerKey {
     $file .= '-key.pem';
 
     if( not $pemData ) {
-#        SCR->Execute( '.target.remove', $file );
-#        $self->ModifyHostKey( $host, 'SSLCertificateKeyFile' );
     } elsif( $pemData !~ /PRIVATE KEY/ ) {
         return $self->SetError( summary => __("Corrupt PEM data."), code => 'CERT_ERROR' );
     } else {
         my $cert = ($pemData =~ /BEGIN CERTIFICATE/)?(1):(0);
         SCR->Write( '.target.string', $file, $pemData );
         SCR->Execute( '.target.bash', "chmod 0400 $file" );
-#        $self->ModifyHostKey( $host, 'SSLCertificateKeyFile', $file );
-#        $self->ModifyHostKey( $host, 'SSLCertificateFile', $file ) if( $cert );
     }
     return $self->ModifyHost( $hostid, $host );
 }
